{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Password recovery" %}{% endblock %}

{% block full_content %}

<div class="container" id="main-container">
  <div class="row">
    <br/>
    <div class='well col-md-6 col-md-offset-3'>
      <h2>Reset your password</h2>
      <p>Enter your username, and you will receive an email with a link to change your password.</p>

        <form method="post" action="{% url "password_reset_recover" %}">

          {% csrf_token %}

          <fieldset>{% for field in form %}
            {% if not field.is_hidden %}
              <div class="fieldWrapper{% if forloop.first %} first{% endif %}{% if forloop.last %} last{% endif %}">
                <p><strong>Username:</strong></p>
                {{ field }}
                {{ field.errors }}
              </div>
            {% else %}
              {{ field }}
            {% endif %}
          {% endfor %}</fieldset>
          </br>
          <p><input class="btn btn-default" type="submit" value="{% trans 'Send email' %}"></p>
        </form>

    </div>
  </div>
</div>

{% endblock %}