{% extends "base.html" %}
{% block title %}Sign in{% endblock %}
{% block full_content %}

<div class="container" id="main-container">
  <div class="row">
  <br/>
    <div class='well col-md-6 col-md-offset-3'>
      <h2>Success!</h2>
      <p>You changed your password. You can return to your <a href="{% url 'subscriptions_manage' %}">management page</a> or continue to peruse <a href="/">Councilmatic</a>.</p>
    </div>
  </div>
</div>

{% endblock %}