{% extends "password_reset/base.html" %}{% load i18n %}

{% block title %}{% trans "New password set" %}{% endblock %}

{% block full_content %}
<div class="container" id="main-container">
  <div class="row">
    <br/>
    <div class='well col-md-6 col-md-offset-3'>
      <h2>Success!</h2>
      <p>You successfully reset your passsword. You can use it right now to <a href="/login/">login to Councilmatic</a>.</p>
    </div>
  </div>
</div>

{% endblock %}