{% extends "password_reset/base.html" %}{% load i18n %}

{% block full_content %}

<div class="container" id="main-container">
  <div class="row">
    <br/>
    <div class='well col-md-6 col-md-offset-3'>
      {% if invalid %}{% url "password_reset_recover" as recovery_url %}
        <p>{% blocktrans %}Sorry, this password reset link is invalid. You can still <a href="{{ recovery_url }}">request a new one</a>.{% endblocktrans %}</p>
      {% else %}
        <h2>Choose your new password</h2>

        <form method="post" action="{% url 'password_reset_reset' token %}">
          {% csrf_token %}
          <fieldset>{% for field in form %}
            {% if not field.is_hidden %}
              <div class="fieldWrapper{% if forloop.first %} first{% endif %}{% if forloop.last %} last{% endif %}">
                <p><strong>{{ field.label }}:</strong></p>
                {{ field }}
                {{ field.errors }}
              </div></br>
            {% else %}
              {{ field }}
            {% endif %}
          {% endfor %}</fieldset>
          <p><input class="btn btn-default" type="submit" value="{% trans 'Set password' %}"></p>
        </form>


      {% endif %}
    </div>
  </div>
</div>

{% endblock %}