{% extends "base.html" %}
{% block title %}Sign in{% endblock %}
{% block full_content %}

<div class="container" id="main-container">
  <div class="row">
  <br/>
    <div class='well col-md-6 col-md-offset-3'>
    <h2>Change your password</h2>
    <form role="form" method="POST">
      {% csrf_token %}
      <fieldset>{% for field in form %}
        {% if not field.is_hidden %}
          <div class="fieldWrapper{% if forloop.first %} first{% endif %}{% if forloop.last %} last{% endif %}">
            <p><strong>{{ field.label }}:</strong></p>
            {{ field }}
            {{ field.errors }}
          </div><br>
        {% else %}
          {{ field }}
        {% endif %}
      {% endfor %}</fieldset>
      <button type="submit" class="btn btn-default">Set Password</button>
    </form>
    </div>
  </div>
</div>

{% endblock %}